from docbooktoxtm.main import app

app(prog_name="docbooktoxtm")
